@@ -929,4 +929,4 @@ if __name__ == '__main__':
 
     boggleBoard = BoggleBoard()
     board = boggleBoard.generateBoard(seed=seed)
-    print boggleBoard
+    print(boggleBoard)
